#include <bastard.h>
#include <bdb.h>
#include <extension.h>


/* OUTPUT HLL : Use LANG extension to create .c/etc file */
int plugin_main(FILE *f) {
	if (!f)
		return (sys_set_lasterr(9010));
	return (ext_gen_hll_file(f));
}
